@@ -1,15 +1,18 @@
 import sys
 import os
 import pathlib
+import shutil
 
 import pylogconf.core
 from pytconf import register_endpoint, register_main, config_arg_parse_and_launch
 
+from pydmt.core.pydmt import PyDMT
+from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
+
 from pydmt.features.documentation import Documentation
 from pydmt.features.templating import Templating
 from pydmt.features.yaml import Yaml
-from pydmt.core.pydmt import PyDMT
-from pydmt.static import APP_NAME, VERSION_STR, DESCRIPTION
+from pydmt.features.packages import Packages
 
 
 def add_to_path():
@@ -48,6 +51,8 @@ def build():
     f.setup(p)
     f = Yaml()
     f.setup(p)
+    f = Packages()
+    f.setup(p)
 
     stats = p.build_all()
     sys.exit(stats.get_os_error_code())
@@ -57,7 +62,14 @@ def build():
     description="Clean all generated files"
 )
 def clean() -> None:
-    pass
+    print("TBD")
+
+
+@register_endpoint(
+    description="Clean all files and pydmt cache"
+)
+def clean_hard() -> None:
+    shutil.rmtree(".pydmt")
 
 
 @register_main(
